@@ -1,32 +1,33 @@
-/* 
- * Copyright (C) 1993 Mark Boyns (boyns@sdsu.edu)
+/* version.h - Define the current rplay version.  */
+
+/*
+ * Copyright (C) 1993-98 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of rplay.
  *
- * This program is free software; you can redistribute it and/or modify
+ * rplay is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * rplay is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with Muffin; see the file COPYING.  If not, write to the
+ * Free Software Foundation, Inc.,
+ * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
+
 #ifndef _version_h
 #define _version_h
 
 #define RPLAY_MAJOR_VERSION	3
-#define RPLAY_MINOR_VERSION	1
+#define RPLAY_MINOR_VERSION	3
 #define RPLAY_PATCHLEVEL	0
-
-#define RPLAY_VERSION		30	/* version number sent with rplay packets */
-
-static char	*rplay_version = "rplay 3.1.0"; 
+#define RPLAY_STATUS		""
 
 #endif /* _version_h */
